pub struct ThreadedCpuBackend { /* private fields */ }Expand description
CPU backend with a dedicated rayon thread pool for predictable kernel threading depth.
Implementations
Sourceimpl ThreadedCpuBackend
impl ThreadedCpuBackend
Sourcepub fn new(num_threads: NonZeroUsize) -> Result<Self, KernelError>
pub fn new(num_threads: NonZeroUsize) -> Result<Self, KernelError>
Build a threaded backend with default parallel matmul heuristics.
Sourcepub fn with_config(
num_threads: NonZeroUsize,
matmul_config: ParallelMatmulConfig,
) -> Result<Self, KernelError>
pub fn with_config( num_threads: NonZeroUsize, matmul_config: ParallelMatmulConfig, ) -> Result<Self, KernelError>
Build a threaded backend with explicit parallel-matmul configuration.
Sourcepub fn with_full_config(
num_threads: NonZeroUsize,
config: ThreadedCpuBackendConfig,
) -> Result<Self, KernelError>
pub fn with_full_config( num_threads: NonZeroUsize, config: ThreadedCpuBackendConfig, ) -> Result<Self, KernelError>
Build a threaded backend with explicit matmul and elementwise configuration.
Sourcepub const fn matmul_config(&self) -> ParallelMatmulConfig
pub const fn matmul_config(&self) -> ParallelMatmulConfig
Matmul parallelism knobs used by this backend.
Sourcepub const fn elementwise_config(&self) -> ParallelElementwiseConfig
pub const fn elementwise_config(&self) -> ParallelElementwiseConfig
Elementwise parallelism knobs used by this backend.